==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_signer/paginator.py <==
"""
Type annotations for signer service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_signer.client import SignerClient
    from types_boto3_signer.paginator import (
        ListSigningJobsPaginator,
        ListSigningPlatformsPaginator,
        ListSigningProfilesPaginator,
    )

    session = Session()
    client: SignerClient = session.client("signer")

    list_signing_jobs_paginator: ListSigningJobsPaginator = client.get_paginator("list_signing_jobs")
    list_signing_platforms_paginator: ListSigningPlatformsPaginator = client.get_paginator("list_signing_platforms")
    list_signing_profiles_paginator: ListSigningProfilesPaginator = client.get_paginator("list_signing_profiles")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListSigningJobsRequestListSigningJobsPaginateTypeDef,
    ListSigningJobsResponseTypeDef,
    ListSigningPlatformsRequestListSigningPlatformsPaginateTypeDef,
    ListSigningPlatformsResponseTypeDef,
    ListSigningProfilesRequestListSigningProfilesPaginateTypeDef,
    ListSigningProfilesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListSigningJobsPaginator",
    "ListSigningPlatformsPaginator",
    "ListSigningProfilesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListSigningJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningJobs.html#Signer.Paginator.ListSigningJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningjobspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListSigningJobsRequestListSigningJobsPaginateTypeDef]
    ) -> _PageIterator[ListSigningJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningJobs.html#Signer.Paginator.ListSigningJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningjobspaginator)
        """


class ListSigningPlatformsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningPlatforms.html#Signer.Paginator.ListSigningPlatforms)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningplatformspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListSigningPlatformsRequestListSigningPlatformsPaginateTypeDef]
    ) -> _PageIterator[ListSigningPlatformsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningPlatforms.html#Signer.Paginator.ListSigningPlatforms.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningplatformspaginator)
        """


class ListSigningProfilesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningProfiles.html#Signer.Paginator.ListSigningProfiles)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningprofilespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListSigningProfilesRequestListSigningProfilesPaginateTypeDef]
    ) -> _PageIterator[ListSigningProfilesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningProfiles.html#Signer.Paginator.ListSigningProfiles.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningprofilespaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_signer/paginator.py <==
"""
Type annotations for signer service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_signer.client import SignerClient
    from types_boto3_signer.paginator import (
        ListSigningJobsPaginator,
        ListSigningPlatformsPaginator,
        ListSigningProfilesPaginator,
    )

    session = Session()
    client: SignerClient = session.client("signer")

    list_signing_jobs_paginator: ListSigningJobsPaginator = client.get_paginator("list_signing_jobs")
    list_signing_platforms_paginator: ListSigningPlatformsPaginator = client.get_paginator("list_signing_platforms")
    list_signing_profiles_paginator: ListSigningProfilesPaginator = client.get_paginator("list_signing_profiles")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListSigningJobsRequestPaginateTypeDef,
    ListSigningJobsResponseTypeDef,
    ListSigningPlatformsRequestPaginateTypeDef,
    ListSigningPlatformsResponseTypeDef,
    ListSigningProfilesRequestPaginateTypeDef,
    ListSigningProfilesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListSigningJobsPaginator",
    "ListSigningPlatformsPaginator",
    "ListSigningProfilesPaginator",
)


if TYPE_CHECKING:
    _ListSigningJobsPaginatorBase = Paginator[ListSigningJobsResponseTypeDef]
else:
    _ListSigningJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListSigningJobsPaginator(_ListSigningJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningJobs.html#Signer.Paginator.ListSigningJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSigningJobsRequestPaginateTypeDef]
    ) -> PageIterator[ListSigningJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningJobs.html#Signer.Paginator.ListSigningJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningjobspaginator)
        """


if TYPE_CHECKING:
    _ListSigningPlatformsPaginatorBase = Paginator[ListSigningPlatformsResponseTypeDef]
else:
    _ListSigningPlatformsPaginatorBase = Paginator  # type: ignore[assignment]


class ListSigningPlatformsPaginator(_ListSigningPlatformsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningPlatforms.html#Signer.Paginator.ListSigningPlatforms)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningplatformspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSigningPlatformsRequestPaginateTypeDef]
    ) -> PageIterator[ListSigningPlatformsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningPlatforms.html#Signer.Paginator.ListSigningPlatforms.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningplatformspaginator)
        """


if TYPE_CHECKING:
    _ListSigningProfilesPaginatorBase = Paginator[ListSigningProfilesResponseTypeDef]
else:
    _ListSigningProfilesPaginatorBase = Paginator  # type: ignore[assignment]


class ListSigningProfilesPaginator(_ListSigningProfilesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningProfiles.html#Signer.Paginator.ListSigningProfiles)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningprofilespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSigningProfilesRequestPaginateTypeDef]
    ) -> PageIterator[ListSigningProfilesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer/paginator/ListSigningProfiles.html#Signer.Paginator.ListSigningProfiles.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_signer/paginators/#listsigningprofilespaginator)
        """
